@@ -2,7 +2,6 @@ from sqlalchemy import Table, MetaData, Column, JSON
 from sqlalchemy.ext.mutable import MutableDict
 from sqlalchemy.ext.automap import automap_base
 from sqlalchemy.ext.declarative import declarative_base
-from .__init__ import PipelineDataApp as app
 
 from sqlalchemy.orm.attributes import flag_modified
 
@@ -17,9 +16,14 @@ class StateMachineRun(Base):
         Column("result", MutableDict.as_mutable(JSON)),
         autoload=True,
     )
+    
+    def __init__(self, app) -> None:
+        self.app = app
+
+        pass
 
     def result_to_db(self, logical_step_name, state_machine_run_id, results):
-        sm_run = app.db.query(StateMachineRun).get(state_machine_run_id)
+        sm_run = self.app.db.query(StateMachineRun).get(state_machine_run_id)
         sm_run.result[logical_step_name] = results
 
         return app.db.commit()
